@@ -7,20 +7,13 @@ if [ -z "$srcdir" ]; then
     srcdir="$(dirname "$0")"
 fi
 
-if [ 1 = 1 ]; then
-    python2 ${srcdir}/libbytesize_unittest.py || status=1
-fi
-
 if [ 1 = 1 ]; then
     python3 ${srcdir}/libbytesize_unittest.py || status=1
+    python3 ${srcdir}/lbs_py_override_unittest.py || status=1
 fi
 
 if [ 1 = 1 ]; then
-    python2 ${srcdir}/libbytesize_unittest.py fr_FR.UTF8 || status=1
-fi
-
-if [ 1 = 1 ]; then
-    python3 ${srcdir}/libbytesize_unittest.py fr_FR.UTF8 || status=1
+    python3 ${srcdir}/libbytesize_unittest.py fr_FR.UTF-8 || status=1
 fi
 
 exit $status
